@@ -593,12 +593,8 @@ eval_expr(node_t *np, pmResult *rp, int level)
 		else {
 		    /* rate() conversion, type will be DOUBLE */
 		    struct timeval	stampdiff;
-		    stampdiff.tv_sec = np->info->stamp.tv_sec - np->info->last_stamp.tv_sec;
-		    stampdiff.tv_usec = np->info->stamp.tv_usec - np->info->last_stamp.tv_usec;
-		    if (stampdiff.tv_usec < 0) {
-			stampdiff.tv_usec += 1000000;
-			stampdiff.tv_sec--;
-		    }
+		    stampdiff = np->info->stamp;
+		    __pmtimevalDec(&stampdiff, &np->info->last_stamp);
 		    switch (np->left->desc.type) {
 			case PM_TYPE_32:
 			    np->info->ivlist[k].value.d = (double)(np->left->info->ivlist[i].value.l - np->left->info->last_ivlist[j].value.l);
@@ -625,7 +621,7 @@ eval_expr(node_t *np, pmResult *rp, int level)
 			     */
 			    return PM_ERR_CONV;
 		    }
-		    np->info->ivlist[k].value.d /= stampdiff.tv_sec + (double)stampdiff.tv_usec/1000000;
+		    np->info->ivlist[k].value.d /= __pmtimevalToReal(&stampdiff);
 		    /*
 		     * check_expr() ensures dimTime is 0 or 1 at bind time
 		     */
