@@ -287,8 +287,7 @@ findFetch(Host *h, Metric *m)
 	    int tmp_mode = PM_MODE_INTERP;
 	    getDoubleAsXTB(&h->task->delta, &tmp_ival, &tmp_mode);
 
-	    tv.tv_sec = (time_t)start;
-	    tv.tv_usec = (int)((start - tv.tv_sec) * 1000000.0);
+	    __pmtimevalFromReal(start, &tv);
 	    if ((sts = pmSetMode(tmp_mode, &tv, tmp_ival)) < 0) {
 		fprintf(stderr, "%s: pmSetMode failed: %s\n", pmProgname,
 			pmErrStr(sts));
@@ -522,7 +521,7 @@ initArchive(Archive *a)
 	pmDestroyContext(handle);
 	return 0;
     }
-    a->first = realize(label.ll_start);
+    a->first = __pmtimevalToReal(&label.ll_start);
     if ((sts = pmGetArchiveEnd(&tv)) < 0) {
 	fprintf(stderr, "%s: archive %s is corrupted\n"
 		"pmGetArchiveEnd failed: %s\n",
@@ -530,7 +529,7 @@ initArchive(Archive *a)
 	pmDestroyContext(handle);
 	return 0;
     }
-    a->last = realize(tv);
+    a->last = __pmtimevalToReal(&tv);
 
     /* check for duplicate host */
     b = archives;
@@ -1176,7 +1175,7 @@ taskFetch(Task *t)
 			    if (m->desc.pmid == r->vset[i]->pmid) {
 				if (r->vset[i]->numval > 0) {
 				    m->vset = r->vset[i];
-				    m->stamp = realize(r->timestamp);
+				    m->stamp = __pmtimevalToReal(&r->timestamp);
 				}
 				break;
 			    }
