@@ -221,12 +221,7 @@ ParseSize(char *size_arg, int *sample_counter, __int64_t *byte_size,
 static void
 tsub(struct timeval *a, struct timeval *b)
 {
-    a->tv_usec -= b->tv_usec;
-    if (a->tv_usec < 0) {
-        a->tv_usec += 1000000;
-        a->tv_sec--;
-    }
-    a->tv_sec -= b->tv_sec;
+    __pmtimevalDec(a, b);
     if (a->tv_sec < 0) {
         /* clip negative values at zero */
         a->tv_sec = 0;
@@ -518,13 +513,13 @@ main(int argc, char **argv)
 		configfile = opts.optarg;
 	    else {
 		/* does not exist as given, try the standard place */
-		char *sysconf = pmGetConfig("PCP_SYSCONF_DIR");
-		int sz = strlen(sysconf)+strlen("/pmlogger/")+strlen(opts.optarg)+1;
+		char *sysconf = pmGetConfig("PCP_VAR_DIR");
+		int sz = strlen(sysconf)+strlen("/config/pmlogger/")+strlen(opts.optarg)+1;
 		if ((configfile = (char *)malloc(sz)) == NULL)
 		    __pmNoMem("config file name", sz, PM_FATAL_ERR);
 		snprintf(configfile, sz,
-			"%s%c" "pmlogger" "%c%s",
-			sysconf, sep, sep, opts.optarg);
+			"%s%c" "config%c" "pmlogger%c" "%s",
+			sysconf, sep, sep, sep, opts.optarg);
 		if (access(configfile, F_OK) != 0) {
 		    /* still no good, error handling happens below */
 		    free(configfile);
